@@ -396,9 +396,9 @@ def test_arbitrary_status_code():
     @responses.activate
     def run():
         url = "http://example.com/"
-        responses.add(responses.GET, url, body="test", status=418)
+        responses.add(responses.GET, url, body="test", status=419)
         resp = requests.get(url)
-        assert resp.status_code == 418
+        assert resp.status_code == 419
         assert resp.reason is None
 
     run()
@@ -1122,23 +1122,109 @@ def test_cookies_from_headers():
         assert v == expected[k]
 
 
-def test_request_param():
+@pytest.mark.parametrize(
+    "url",
+    (
+        "http://example.com",
+        "http://example.com/some/path",
+        "http://example.com/other/path/",
+    ),
+)
+def test_request_param(url):
     @responses.activate
     def run():
         params = {"hello": "world", "example": "params"}
         responses.add(
             method=responses.GET,
-            url="http://example.com?hello=world",
+            url="{0}?hello=world".format(url),
             body="test",
             match_querystring=False,
         )
-        resp = requests.get("http://example.com", params=params)
+        resp = requests.get(url, params=params)
         assert_response(resp, "test")
         assert resp.request.params == params
 
-        resp = requests.get("http://example.com")
+        resp = requests.get(url)
         assert_response(resp, "test")
         assert resp.request.params == {}
 
     run()
     assert_reset()
+
+
+@pytest.mark.parametrize(
+    "url", ("http://example.com", "http://example.com?hello=world")
+)
+def test_assert_call_count(url):
+    @responses.activate
+    def run():
+        responses.add(responses.GET, url)
+        responses.add(responses.GET, "http://example1.com")
+
+        assert responses.assert_call_count(url, 0) is True
+
+        with pytest.raises(AssertionError) as excinfo:
+            responses.assert_call_count(url, 2)
+        assert "Expected URL '{0}' to be called 2 times. Called 0 times.".format(
+            url
+        ) in str(excinfo.value)
+
+        requests.get(url)
+        assert responses.assert_call_count(url, 1) is True
+
+        requests.get("http://example1.com")
+        assert responses.assert_call_count(url, 1) is True
+
+        requests.get(url)
+        with pytest.raises(AssertionError) as excinfo:
+            responses.assert_call_count(url, 3)
+        assert "Expected URL '{0}' to be called 3 times. Called 2 times.".format(
+            url
+        ) in str(excinfo.value)
+
+    run()
+    assert_reset()
+
+
+def test_request_matches_post_params():
+    @responses.activate
+    def run():
+        responses.add(
+            method=responses.POST,
+            url="http://example.com/",
+            body="one",
+            match=[
+                responses.json_params_matcher(
+                    {"page": {"name": "first", "type": "json"}}
+                )
+            ],
+        )
+        responses.add(
+            method=responses.POST,
+            url="http://example.com/",
+            body="two",
+            match=[
+                responses.urlencoded_params_matcher(
+                    {"page": "second", "type": "urlencoded"}
+                )
+            ],
+        )
+
+        resp = requests.request(
+            "POST",
+            "http://example.com/",
+            headers={"Content-Type": "x-www-form-urlencoded"},
+            data={"page": "second", "type": "urlencoded"},
+        )
+        assert_response(resp, "two")
+
+        resp = requests.request(
+            "POST",
+            "http://example.com/",
+            headers={"Content-Type": "application/json"},
+            json={"page": {"name": "first", "type": "json"}},
+        )
+        assert_response(resp, "one")
+
+    run()
+    assert_reset()
